@@ -24,17 +24,17 @@
 #' between them than the specified gap era will be concatenated into a single
 #' cohort entry.
 #'
-#' @param cdm A cdm reference.
-#' @param name The name of the new cohort table to add to the cdm reference.
+#' @inheritParams cdmDoc
+#' @inheritParams newNameDoc
 #' @param atcName Names of ATC classification of interest.
-#' @param level ATC level. Can be one or more of "ATC 1st", "ATC 2nd",
-#' "ATC 3rd", "ATC 4th", and "ATC 5th"
-#' @param doseForm Only descendants codes with the specified dose form
-#' will be returned. If NULL, descendant codes will be returned regardless
-#' of dose form.
 #' @param gapEra Number of days between two continuous exposures to be
 #' considered in the same era. Records that have fewer days between them than
 #' this gap will be concatenated into the same cohort record.
+#' @param subsetCohort Cohort table to subset.
+#' @param subsetCohortId Cohort id to subset.
+#' @inheritParams numberExposuresDoc
+#' @inheritParams daysPrescribedDoc
+#' @param ... Arguments to be passed to `CodelistGenerator::getATCCodes()`.
 #' @param durationRange Deprecated.
 #' @param imputeDuration Deprecated.
 #' @param priorUseWashout Deprecated
@@ -66,73 +66,34 @@
 generateAtcCohortSet <- function(cdm,
                                  name,
                                  atcName = NULL,
-                                 level = c("ATC 1st"),
-                                 doseForm = NULL,
                                  gapEra = 1,
+                                 subsetCohort = NULL,
+                                 subsetCohortId = NULL,
+                                 numberExposures = FALSE,
+                                 daysPrescribed = FALSE,
+                                 ...,
                                  durationRange = lifecycle::deprecated(),
                                  imputeDuration = lifecycle::deprecated(),
                                  priorUseWashout = lifecycle::deprecated(),
                                  priorObservation = lifecycle::deprecated(),
                                  cohortDateRange = lifecycle::deprecated(),
                                  limit = lifecycle::deprecated()) {
-  if (lifecycle::is_present(durationRange)) {
-    lifecycle::deprecate_warn(
-      when = "0.7.0",
-      what = "generateAtcCohortSet(durationRange = )"
-    )
-  }
-  if (lifecycle::is_present(imputeDuration)) {
-    lifecycle::deprecate_warn(
-      when = "0.7.0", what = "generateAtcCohortSet(imputeDuration = )"
-    )
-  }
-  if (lifecycle::is_present(priorUseWashout)) {
-    lifecycle::deprecate_warn(
-      when = "0.7.0",
-      what = "generateAtcCohortSet(priorUseWashout = )",
-      with = "requirePriorDrugWashout()"
-    )
-  }
-  if (lifecycle::is_present(priorObservation)) {
-    lifecycle::deprecate_warn(
-      when = "0.7.0",
-      what = "generateAtcCohortSet(priorObservation = )",
-      with = "requireObservationBeforeDrug()"
-    )
-  }
-  if (lifecycle::is_present(cohortDateRange)) {
-    lifecycle::deprecate_warn(
-      when = "0.7.0",
-      what = "generateAtcCohortSet(cohortDateRange = )",
-      with = "requireDrugInDateRange()"
-    )
-  }
-  if (lifecycle::is_present(limit)) {
-    lifecycle::deprecate_warn(
-      when = "0.7.0",
-      what = "generateAtcCohortSet(limit = )",
-      with = "requireIsFirstDrugEntry()"
-    )
-  }
-
-  conceptSet <- CodelistGenerator::getATCCodes(cdm,
-    name = atcName,
-    level = level,
-    doseForm = doseForm
-  )
-
-  cdm <- DrugUtilisation::generateDrugUtilisationCohortSet(
+  generateSubFunctions(
+    type = "atc",
     cdm = cdm,
     name = name,
-    conceptSet = conceptSet,
-    gapEra = gapEra
+    nam = atcName,
+    gapEra = gapEra,
+    subsetCohort = subsetCohort,
+    subsetCohortId = subsetCohortId,
+    numberExposures = numberExposures,
+    daysPrescribed = daysPrescribed,
+    ...,
+    durationRange = durationRange,
+    imputeDuration = imputeDuration,
+    priorUseWashout = priorUseWashout,
+    priorObservation = priorObservation,
+    cohortDateRange = cohortDateRange,
+    limit = limit
   )
-
-  cdm[[name]] <- cdm[[name]] |>
-    omopgenerics::newCohortTable(
-      cohortSetRef = settings(cdm[[name]]) |>
-        dplyr::mutate("dose_form" = paste0(.env$doseForm, collapse = " "))
-    )
-
-  return(cdm)
 }
